"""
Format by row, or format by columns.

By row:
- apply one format to the whole row
- apply one format to alternating rows, or two formats to alternating rows
- band rows on changes in a given field value
- conditionally format an entire row (function of one or more row values)

By column:
- apply one format to the whole column
- apply a given format if value tests as True, no format otherwise
- apply one or more formats based on the results of an arbitrary function

"""

